# PAX25

pax25 is intended to be a full AX.25 stack with:

AX.25 V2 stack (not 2.2; no MOD128, no SREJ, no XID)
Multiple physical interfaces (KISS, AXIP) support

Target Python is 3.11. Earlier versions of the 3.X branch may be supported but are untested.

## Getting Started

This library can be installed 'as-is' by entering the root of the repository and running:

```bash
pip install .
```

The documentation is not yet publicly published, but you can read and build it for local use by following the directions in the [development setup guide](documentation/contributing/development_setup.md).
